# mojave
Tooig Operating System

Mojave is an architecture designed stritly to deliver on automation. 

We designed it to help manage certain backend functions that will bug the process of software and operations at Tooig in the future. it is also versatile enough that it can be used to develop other smaller variants.